==> crypto-2.6.1.tgz: package/Cs/Cs.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const Cs = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 32 32"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M16.931 9.625c.061-1.188.454-3.826 1.704-3.826.33 0 .601.094.812.282-.3.157-.451.423-.451.8 0 .563.473.94.947.94.473 0 .946-.283.946-.94C20.89 6.221 20.26 5 18.77 5c-2.458.046-3.42 2.855-3.469 4.695-2.501.395-5.051 2.165-5.051 6.258 0 3.64 2.449 6.143 5.077 6.565-.116 2.098-.794 3.73-1.696 3.73-.27 0-.54-.094-.811-.282.27-.157.405-.439.405-.846 0-.611-.45-.94-.901-.94s-.947.282-.947.94c0 1.01.947 1.88 2.074 1.88 2.38 0 3.34-2.444 3.527-4.473 2.49-.311 4.272-1.883 4.272-2.578 0-.33-.225-.47-.406-.47-.325 0-1.577 1.684-3.832 2.013-.006-2.175-.068-8.495-.085-10.791.846.047 1.574.273 2.294 1.35.668 1 .541 1.505.992 1.505.3 0 .466-.126.496-.377-.12-.365-.18-.632-.18-.799 0-.25.045-.658.045-.846 0-.264-1.19-1.728-3.643-1.909zm-1.587 11.788c-1.726-.521-3.11-2.532-3.11-5.46 0-1.847.76-4.593 3.067-5.16.008 2.577.039 8.186.043 10.62zM16 32C7.163 32 0 24.837 0 16S7.163 0 16 0s16 7.163 16 16-7.163 16-16 16z"
  }));
});
Cs.displayName = 'Cs';
export const CsDimensions = {
  height: 32,
  width: 32
};

==> crypto-2.7.1.tgz: package/Cs/Cs.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Cs = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 32 32"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M16.931 9.625c.061-1.188.454-3.826 1.704-3.826.33 0 .601.094.812.282-.3.157-.451.423-.451.8 0 .563.473.94.947.94.473 0 .946-.283.946-.94C20.89 6.221 20.26 5 18.77 5c-2.458.046-3.42 2.855-3.469 4.695-2.501.395-5.051 2.165-5.051 6.258 0 3.64 2.449 6.143 5.077 6.565-.116 2.098-.794 3.73-1.696 3.73-.27 0-.54-.094-.811-.282.27-.157.405-.439.405-.846 0-.611-.45-.94-.901-.94s-.947.282-.947.94c0 1.01.947 1.88 2.074 1.88 2.38 0 3.34-2.444 3.527-4.473 2.49-.311 4.272-1.883 4.272-2.578 0-.33-.225-.47-.406-.47-.325 0-1.577 1.684-3.832 2.013-.006-2.175-.068-8.495-.085-10.791.846.047 1.574.273 2.294 1.35.668 1 .541 1.505.992 1.505.3 0 .466-.126.496-.377-.12-.365-.18-.632-.18-.799 0-.25.045-.658.045-.846 0-.264-1.19-1.728-3.643-1.909zm-1.587 11.788c-1.726-.521-3.11-2.532-3.11-5.46 0-1.847.76-4.593 3.067-5.16.008 2.577.039 8.186.043 10.62zM16 32C7.163 32 0 24.837 0 16S7.163 0 16 0s16 7.163 16 16-7.163 16-16 16z"
  }));
});
Cs.displayName = 'Cs';
export var CsDimensions = {
  height: 32,
  width: 32
};
